@@ -90,6 +90,8 @@
 
 extern server_info_t info;
 
+static void client_send_fake_file (connection_t *con);
+
 /* Brand new client. Check what he wants, and either add him to
    the correct tree of clients (inside a source), or kill him off */
 void client_login(connection_t *con, char *expr)
@@ -412,18 +414,18 @@ show_mountlist(connection_t *con, request_t *req)
 
 void util_increase_total_clients ()
 {
-	thread_mutex_lock (&info.misc_mutex);
+	internal_lock_mutex (&info.misc_mutex);
 	info.num_clients++;
 	info.hourly_stats.client_connections++;
-	thread_mutex_unlock (&info.misc_mutex);
+	internal_unlock_mutex (&info.misc_mutex);
 }
 
 void
 util_decrease_total_clients ()
 {
-	thread_mutex_lock (&info.misc_mutex);
+	internal_lock_mutex (&info.misc_mutex);
 	info.num_clients--;
-	thread_mutex_unlock (&info.misc_mutex);
+	internal_unlock_mutex (&info.misc_mutex);
 }
 
 void 
@@ -485,11 +487,11 @@ client_wants_icy_headers (connection_t *con)
 	const char *val;
 
 	if (!con)
-		return 0;
+		return 1;
 
 	val = get_user_agent (con);
-	if (!val)
-		return 0;
+	if (!val || !val[0] || strcmp (val, "(null)") == 0)
+		return 1;
 
 	if (con->food.client->use_icy)
 		return 1;
@@ -497,14 +499,7 @@ client_wants_icy_headers (connection_t *con)
 		return 1;
 	if (strncasecmp (val, "Shoutcast", 9) == 0)
 		return 1;
-	if (con->hostname)
-		if (wild_match ((unsigned char *) "*.winamp.com", (unsigned char *)con->hostname) ||
-		    wild_match ((unsigned char *) "205.188.245.*", (unsigned char *)con->hostname))
-			return 1;
-	if (con->host)
-		if (wild_match ((unsigned char *) "*.winamp.com", (unsigned char *)con->host) ||
-		    wild_match ((unsigned char *) "205.188.245.*", (unsigned char *)con->host))
-			return 1;
+
 	return 0;
 }
 
@@ -561,24 +556,25 @@ greet_client(connection_t *con, source_t *source)
 
 	con->food.client->udpseqnr = source->info.udpseqnr > 0 ? source->info.udpseqnr - 1 : source->info.udpseqnr;
 
-	if (client_wants_icy_headers (con))	{
-		xa_debug (2, "DEBUG: client [%s] wants icy headers", con_host (con));
-		sock_write_line (con->sock, "ICY 200 OK");
-		sock_write_line (con->sock, 
-			       "icy-notice1:<BR>This stream requires <a href=\"http://www.winamp.com/\">Winamp</a><BR>");
-		sock_write_line (con->sock, "icy-notice2:SHOUTcast Distributed Network Audio Server/posix v1.6.0rc2<BR>");
-		
-		if (client_wants_metadata (con))
-			sock_write_line (con->sock, "icy-metaint:%u", info.metainterval);
-		
-		if (client_wants_udp_info (con))
-			sock_write_line (con->sock, "x-audiocast-udpport: %d", info.port[0]);
-		
-		sock_write (con->sock, "icy-name:%s\r\nicy-genre:%s\r\nicy-url:%s\r\nicy-pub:%d\nicy-br:%d\r\n\r\n",
-			    source->audiocast.name, source->audiocast.genre, source->audiocast.url, source->audiocast.public,
-			    source->audiocast.bitrate);
+	if (client_wants_icy_headers (con)) {
+		  xa_debug (2, "DEBUG: client [%s] wants icy headers", con_host (con));
+		  sock_write_line (con->sock, "ICY 200 OK");
+		  sock_write_line (con->sock, 
+		  "icy-notice1:<BR>This stream requires <a href=\"http://www.winamp.com/\">Winamp</a><BR>");
+		  sock_write_line (con->sock, "icy-notice2:SHOUTcast Distributed Network Audio Server/posix v1.6.0rc2<BR>");
+		  
+		  if (client_wants_metadata (con))
+		  sock_write_line (con->sock, "icy-metaint:%u", info.metainterval);
+		  
+		  if (client_wants_udp_info (con))
+		  sock_write_line (con->sock, "x-audiocast-udpport: %d", info.port[0]);
+		  
+		  sock_write (con->sock, "icy-name:%s\r\nicy-genre:%s\r\nicy-url:%s\r\nicy-pub:%d\nicy-br:%d\r\n\r\n",
+		  source->audiocast.name, source->audiocast.genre, source->audiocast.url, source->audiocast.public,
+		  source->audiocast.bitrate); 
 	} else {
-		
+	  xa_debug (2, "DEBUG: client [%s] wants xaudiocast headers", con_host (con));
+	  
 	  write_http_header (con->sock, 200, "OK");
 	  if (source->audiocast.streammimetype)
 		  sock_write_line (con->sock, "Content-Type: %s", source->audiocast.streammimetype);
