@@ -726,13 +726,18 @@ add_chunk (connection_t *con)
 
 	if (con->food.source->chunk[con->food.source->cid].clients_left > 0)
 	{
+		connection_t *smaller = get_twin_mount_wl (con->food.source);
 #ifndef OPTIMIZE
 		xa_debug (2, "DEBUG: Kicking trailing clients [%d] on id %d", con->food.source->chunk[con->food.source->cid].clients_left, 
 			con->food.source->cid);
 #endif
+		thread_mutex_lock (&info.double_mutex);
 		thread_mutex_lock (&con->food.source->mutex);
-		kick_clients_on_cid (con->food.source);
+
+		kick_clients_on_cid (con->food.source, smaller);
+
 		thread_mutex_unlock (&con->food.source->mutex);
+		thread_mutex_unlock (&info.double_mutex);
 	}
 	
 	len = 0;
@@ -907,8 +912,8 @@ write_chunk(source_t *source, connection_t *clicon)
 	int i = 0;
 	long int write_bytes = 0, len = 0;
 
-	/* Try to write 1 time */
-	for (i = 0; i < 1; i++)
+	/* Try to write 2 times */
+	for (i = 0; i < 2; i++)
 	{
 		/* We caught up with the source */
 		if (source->cid == clicon->food.client->cid) /* No more data available */
@@ -983,8 +988,8 @@ write_chunk_with_metadata (source_t *source, connection_t *clicon)
 	int i = 0;
 	long int write_bytes = 0, len = 0, sourcelen = 0, justnull = 0;
 
-	/* Try to write 1 time */
-	for (i = 0; i < 1; i++)
+	/* Try to write 2 times */
+	for (i = 0; i < 2; i++)
 	{
 		/* We caught up with the source */
 		if (source->cid == clicon->food.client->cid) /* No more data available */
@@ -1062,7 +1067,7 @@ write_chunk_with_metadata (source_t *source, connection_t *clicon)
 }
 
 void 
-kick_clients_on_cid(source_t *source)
+kick_clients_on_cid(source_t *source, connection_t *smaller)
 {
 	avl_traverser trav = {0};
 	connection_t *clicon;
@@ -1082,12 +1087,9 @@ kick_clients_on_cid(source_t *source)
 		if (!clicon)
 			break;
 		
-		xa_debug (1, "REMOVE: %d == %d && %d < %d", clicon->food.client->cid, source->cid, client_errors (clicon->food.client), CHUNKLEN - 2);
 		if (client_errors (clicon->food.client) >= (CHUNKLEN - 1) && clicon->food.client->alive != CLIENT_DEAD)
 		    
 		{
-			connection_t *smaller = get_twin_mount_wl (source);
-
 			if (smaller)
 			{
 				write_log (LOG_DEFAULT, "Moving client %d [%s] from mount %s to lower bitrate on mount %s",
@@ -1422,6 +1424,7 @@ describe_source (const com_request_t *req, const connection_t *sourcecon)
 	admin_write_line (req, ADMIN_SHOW_DESCRIBE_SOURCE_MISC, "Client connect time: %s", nice_time_minutes (source->stats.client_connect_time, buf));
 	admin_write_line (req, ADMIN_SHOW_DESCRIBE_SOURCE_MISC, "Average client connect time: %s", connect_average (source->stats.client_connect_time, source->stats.client_connections, buf));
 	admin_write_line (req, ADMIN_SHOW_DESCRIBE_SOURCE_MISC, "Average client transfer: %lu", transfer_average (source->stats.write_megs, source->stats.client_connections));
+	admin_write_line (req, ADMIN_SHOW_DESCRIBE_SOURCE_MISC, "Stream Song Counter: %lu", source->info.udpseqnr);
 
 	admin_write_line (req, ADMIN_SHOW_DESCRIBE_SOURCE_END, "End of source info");
 }
@@ -1526,14 +1529,15 @@ source_write_to_client (source_t *source, connection_t *clicon)
 	if (client->virgin == 1) {
 		client->cid = start_chunk (source); 
 		client->offset = find_frame_ofs(source);
+		xa_debug (2, "Client got offset %d", client->offset);
 		client->virgin = 0;
 		source->num_clients = source->num_clients + (unsigned long int)1;
 	}
 	
-	if (clicon->food.client->use_icy_metadata && info.use_meta_data && (client->cid % (info.metainterval / 4096) == 0))
-		write_chunk_with_metadata (source, clicon);
+	if (clicon->food.client->use_icy_metadata && info.use_meta_data)
+	  write_chunk_with_metadata (source, clicon);
 	else
-		write_chunk (source, clicon);
+	  write_chunk (source, clicon);
 }
 
 /* Sleep for chunksize / byterate / 10 seconds */
