@@ -157,12 +157,11 @@ print_admin (void *data, void *param)
 	if (param)
 		sock = (sock_t *)param;
 
-	sprintf (buf, "Admin %ld\t[%s] connected for %s. %d commands issued.\tFlags:", con->id, 
+	snprintf (buf, BUFSIZE, "Admin %ld\t[%s] connected for %s. %d commands issued.\tFlags:", con->id, 
 		 con_host (con), nice_time (get_time () - con->connect_time, timebuf), admin->commands);
 	
 	if (!param) {
-		fd_write (info.statsfile, 
-			 buf);
+		fd_write (info.statsfile, "%s", buf);
 		flags2string (admin, NULL);
 		fd_write (info.statsfile, "\n");
 	} else {
@@ -194,11 +193,11 @@ print_connection (void *data, void *param)
 	else
 		type = "unknown";
 
-	sprintf (buf, "%ld\t [%s] connected for %s. Type: [%s]\r\n", con->id, con_host (con), 
+	snprintf (buf, BUFSIZE, "%ld\t [%s] connected for %s. Type: [%s]\r\n", con->id, con_host (con), 
 		 nice_time (get_time () - con->connect_time, timebuf), type);
 
 	if (!param)
-		fd_write (info.statsfile, buf);
+		fd_write (info.statsfile, "%s", buf);
 	else
 		sock_write (*sock, "%s", buf);
 }
@@ -217,13 +216,13 @@ print_source(void *data, void *param)
 	if (param)
 		sock = (sock_t *)param;
 	
-	sprintf (buf, "Source %ld\t[%s] connected for %s, %lu megs transfered, type: %s, streaming to %lu clients.\r\n",
+	snprintf (buf, BUFSIZE, "Source %ld\t[%s] connected for %s, %lu megs transfered, type: %s, streaming to %lu clients.\r\n",
 		 con->id, con_host (con), nice_time (get_time() - con->connect_time, timebuf), 
 		 source->stats.read_megs, source->type == encoder_e ? "encoder" : "relay", 
 		 source->num_clients);
 	
 	if (!param)
-		fd_write (info.statsfile, buf);
+		fd_write (info.statsfile, "%s", buf);
 	else
 		sock_write (*sock, "%s", buf);
 }
@@ -244,30 +243,30 @@ print_source_verbose (void *data, void *param)
 	if (param)
 		sock = (sock_t *)param;
 	
-	sprintf (buf, "Source %lu\t[%s] connected for %s, %lu megs transfered, type: %s, streaming to %lu clients, priority: %d, ",
+	snprintf (buf, BUFSIZE, "Source %lu\t[%s] connected for %s, %lu megs transfered, type: %s, streaming to %lu clients, priority: %d, ",
 		 con->id, con_host (con), nice_time (get_time() - con->connect_time, timebuf), source->stats.read_megs, 
 		 source->type == encoder_e ? "encoder" : "relay", (unsigned long int) avl_count (source->clients), source->priority);
 
 	if (source->dumpfile)
 	{
-		sprintf (buf2, "%sdumping to [%s]\r\n", buf, source->dumpfile);
+		snprintf (buf2, BUFSIZE, "%sdumping to [%s]\r\n", buf, source->dumpfile);
 		strncpy (buf, buf2, BUFSIZE);
 	} else {
 		strcat (buf, "not dumping to any file\r\n");
 	}
 
 	if (!param)
-		fd_write (info.statsfile, buf);
+		fd_write (info.statsfile, "%s", buf);
 	else
 		sock_write (*sock, "%s", buf);
 
-	sprintf (buf, "\tStream Title: %s\r\n\tStream URL: %s\tx-audiocast-name: %s\r\n\tx-audiocast-genre: %s\r\n\tx-audiocast-bitrate: %d\r\n\tx-audiocast-url: %s\r\n\tx-audiocast-mount: %s\r\n\tx-audiocast-description: %s\r\n\tx-audiocast-public: %d\r\n",
+	snprintf (buf, BUFSIZE, "\tStream Title: %s\r\n\tStream URL: %s\tx-audiocast-name: %s\r\n\tx-audiocast-genre: %s\r\n\tx-audiocast-bitrate: %d\r\n\tx-audiocast-url: %s\r\n\tx-audiocast-mount: %s\r\n\tx-audiocast-description: %s\r\n\tx-audiocast-public: %d\r\n",
 		 source->info.streamtitle ? source->info.streamtitle : "n/a", source->info.streamurl ? source->info.streamurl : "n/a",
 		 source->audiocast.name, source->audiocast.genre, source->audiocast.bitrate, source->audiocast.url, 
 		 source->audiocast.mount, source->audiocast.description, source->audiocast.public);
 	
 	if (!param)
-		fd_write (info.statsfile, buf);
+		fd_write (info.statsfile, "%s", buf);
 	else
 		sock_write (*sock, "%s", buf);
 
@@ -325,12 +324,12 @@ print_client(void *data, void *param)
 	
 	client = con->food.client;
 	
-	sprintf (buf, "Client %ld\t[%s] connected for %s, %lu bytes transfered. %d errors. User agent: [%s]. Type: %s\r\n",
+	snprintf (buf, BUFSIZE, "Client %ld\t[%s] connected for %s, %lu bytes transfered. %d errors. User agent: [%s]. Type: %s\r\n",
 		 con->id, con_host (con), nice_time (get_time () - con->connect_time, timebuf), client->write_bytes, client_errors (client), 
 		 get_user_agent (con), client->type == listener_e ? "listener" : "relay");
 	
 	if (!param)
-		fd_write(info.statsfile, buf);
+		fd_write(info.statsfile, "%s", buf);
 	else
 		sock_write (*sock, "%s", buf);
 }
@@ -993,7 +992,7 @@ void
 kick_if_match (char *pattern)
 {
 	char buf[BUFSIZE];
-	sprintf (buf, "Matching %s", pattern);
+	snprintf (buf, BUFSIZE, "Matching %s", pattern);
 	do_if_match_all (pattern, kick_connection, buf, 1);
 }
 
@@ -1322,8 +1321,8 @@ build_request (char *line, request_t *req)
 		if ((splitc (path, line, ' ') == NULL) || !path[0] || path[0] == ' ')
 		{
 			xa_debug (1, "Empty GET request [%s]", line);
-			strcpy (req->path, "");
-			strcpy (req->host, "");
+			strcpy (req->path, "/");
+			strcpy (req->host, info.server_name);
 			req->port = info.port[0];
 			return;
 		}
@@ -1386,7 +1385,7 @@ build_request (char *line, request_t *req)
 			if (pathbuf[0] == '/')
 				strcpy (req->path, pathbuf);
 			else
-				sprintf (req->path, "/%s", pathbuf);
+				snprintf (req->path, BUFSIZE, "/%s", pathbuf);
 
 			if (info.server_name)
 				strcpy (req->host, info.server_name);
@@ -1456,7 +1455,7 @@ generate_request (char *line, request_t *req)
 		return;
 	}
 
-	sprintf (full, "GET %s HTTP/1.0", line);
+	snprintf (full, BUFSIZE, "GET %s HTTP/1.0", line);
 
 	build_request (full, req);
 
@@ -1478,9 +1477,9 @@ generate_http_request (char *line, request_t *req)
 
 	if (ice_strncmp (line, "http://", 7) == 0)
 	{
-		sprintf (full, "GET %s HTTP/1.0", line);
+		snprintf (full, BUFSIZE, "GET %s HTTP/1.0", line);
 	} else {
-		sprintf (full, "GET http://%s HTTP/1.0", line);
+		snprintf (full, BUFSIZE, "GET http://%s HTTP/1.0", line);
 	}
 
 	build_request (full, req);
@@ -1510,7 +1509,7 @@ next_mount_point ()
 			count++;
 	}
 	
-	sprintf (apan, "icy_%d", count);
+	snprintf (apan, BUFSIZE, "icy_%d", count);
 	
 	return &apan[0];
 }
@@ -1729,20 +1728,20 @@ get_log_file (const char *filename)
 		return NULL;
 	}
 
-	sprintf (logdir, "%s%c", info.logdir, DIR_DELIMITER);
+	snprintf (logdir, BUFSIZE, "%s%c", info.logdir, DIR_DELIMITER);
 	xa_debug (1, "DEBUG: Checking directory %s", logdir);
 
 	if (access (info.logdir, R_OK) == 0) {
 		return ice_cat (logdir, filename);
 	}
 
-	sprintf (logdir, "log%c", DIR_DELIMITER);
+	snprintf (logdir, BUFSIZE, "log%c", DIR_DELIMITER);
 	xa_debug (1, "DEBUG: Checking directory %s", logdir);
 	if (access (logdir, R_OK) == 0) {
 		return ice_cat (logdir, filename);
 	}
 
-	sprintf (logdir, "%s%c", ".", DIR_DELIMITER);
+	snprintf (logdir, BUFSIZE, "%s%c", ".", DIR_DELIMITER);
 	if (access (logdir, R_OK) == 0) {
 		return ice_cat (logdir, filename);
 	}
@@ -1764,19 +1763,19 @@ get_icecast_file(const char *filename, filetype_t type, int flags)
 
 	switch (type) {
 		case conf_file_e:
-			sprintf(path_and_file, "%s%c%s", info.etcdir, DIR_DELIMITER, filename);
+			snprintf(path_and_file, BUFSIZE, "%s%c%s", info.etcdir, DIR_DELIMITER, filename);
 			break;
 		case log_file_e:
-			sprintf(path_and_file, "%s%c%s", info.logdir, DIR_DELIMITER, filename);
+			snprintf(path_and_file, BUFSIZE, "%s%c%s", info.logdir, DIR_DELIMITER, filename);
 			break;
 		case template_file_e:
-			sprintf(path_and_file, "%s%c%s", info.templatedir, DIR_DELIMITER, filename);
+			snprintf(path_and_file, BUFSIZE, "%s%c%s", info.templatedir, DIR_DELIMITER, filename);
 			break;
 		case static_file_e:
-			sprintf(path_and_file, "%s%c%s", info.staticdir, DIR_DELIMITER, filename);
+			snprintf(path_and_file, BUFSIZE, "%s%c%s", info.staticdir, DIR_DELIMITER, filename);
 			break;
 		default:
-			sprintf(path_and_file, "%s", filename);
+			snprintf(path_and_file, BUFSIZE, "%s", filename);
 	}
 
 	xa_debug(3, "DEBUG: get_icecast_file(): Looking for %s", path_and_file);
@@ -1786,16 +1785,16 @@ get_icecast_file(const char *filename, filetype_t type, int flags)
 	
 	switch (type) {
 		case conf_file_e:
-			sprintf(path_and_file, ".%c%s%c%s", DIR_DELIMITER, "conf", DIR_DELIMITER, filename);
+			snprintf(path_and_file, BUFSIZE, ".%c%s%c%s", DIR_DELIMITER, "conf", DIR_DELIMITER, filename);
 			break;
 		case log_file_e:
-			sprintf(path_and_file, ".%c%s%c%s", DIR_DELIMITER, "logs", DIR_DELIMITER, filename);
+			snprintf(path_and_file, BUFSIZE, ".%c%s%c%s", DIR_DELIMITER, "logs", DIR_DELIMITER, filename);
 			break;
 		case template_file_e:
-			sprintf(path_and_file, ".%c%s%c%s", DIR_DELIMITER, "templates", DIR_DELIMITER, filename);
+			snprintf(path_and_file, BUFSIZE, ".%c%s%c%s", DIR_DELIMITER, "templates", DIR_DELIMITER, filename);
 			break;
 		default:
-			sprintf(path_and_file, "%s", filename);
+			snprintf(path_and_file, BUFSIZE, "%s", filename);
 	}
 	
 	xa_debug(3, "DEBUG: get_icecast_file(): Looking for %s", path_and_file);
@@ -1805,16 +1804,16 @@ get_icecast_file(const char *filename, filetype_t type, int flags)
 
 	switch (type) {
 		case conf_file_e:
-			sprintf(path_and_file, "..%c%s%c%s", DIR_DELIMITER, "conf", DIR_DELIMITER, filename);
+			snprintf(path_and_file, BUFSIZE, "..%c%s%c%s", DIR_DELIMITER, "conf", DIR_DELIMITER, filename);
 			break;
 		case log_file_e:
-			sprintf(path_and_file, "..%c%s%c%s", DIR_DELIMITER, "logs", DIR_DELIMITER, filename);
+			snprintf(path_and_file, BUFSIZE, "..%c%s%c%s", DIR_DELIMITER, "logs", DIR_DELIMITER, filename);
 			break;
 		case template_file_e:
-			sprintf(path_and_file, "..%c%s%c%s", DIR_DELIMITER, "templates", DIR_DELIMITER, filename);
+			snprintf(path_and_file, BUFSIZE, "..%c%s%c%s", DIR_DELIMITER, "templates", DIR_DELIMITER, filename);
 			break;
 		default:
-			sprintf(path_and_file, "%s", filename);
+			snprintf(path_and_file, BUFSIZE, "%s", filename);
 	}
 	
 	xa_debug(3, "DEBUG: get_icecast_file(): Looking for %s", path_and_file);
